#!/bin/sh

#
# tools/CDWconfig.sh
#
# This file is part of webCDwriter - Network CD/DVD Writing.
#
# Copyright (C) 2005-2007 Jrg P. M. Haeger
#
# webCDwriter is free software. See CDWserver.cpp for details.
#

# directories
export BINDIR=/usr/bin; export CONFIGDIR=/etc/CDWserver; export EXPORTDIR=/var/lib/CDWserver/export; export HTTPDIR=/usr/share/CDWserver/http; export INITDIR=/etc/init.d; export LOGDIR=/var/log/CDWserver; export PROJECTSDIR=/var/lib/CDWserver/projects; export SBINDIR=/usr/sbin; export SPOOLDIR=/var/spool/CDWserver; export TOOLSDIR=/usr/bin

USER=""
GROUP=""
SETUID=off

while [ -n "$1" ]; do
	case $1 in
		group=?*)
			GROUP=`echo $1 | sed "s:group=::g"`
		;;
		--help)
			HELP=yes
		;;
		--noinfo)
			NOINFO=on
		;;
		--norestart)
			NORESTART=on
		;;
		--setuid)
			SETUID=on
		;;
		user=?*)
			USER=`echo $1 | sed "s:user=::g"`
		;;
		*)
			if [ -z "$USER" ]; then
				USER="$1"
			else
				if [ -z "$GROUP" ]; then
					GROUP="$1"
				else
					echo "$1: unknown argument"
					HELP=yes
				fi
			fi
		;;
	esac
	shift
done

if [ "$HELP" ]; then
	cat <<EOF

Usage: $0 [options] user group

In the case of problems try

	$0 root root

On Linux < 2.6.7 use

	$0 --setuid cdwserve cdwserve

Ubuntu Linux 5.04 works well with

	$0 cdwserve cdrom

EOF
	exit 1
fi

if [ `id -u` != "0" ]; then
	echo
	echo "Run $0 as root!"
	echo
	exit 1
fi

if [ -z "$USER" ] || [ -z "$GROUP" ]; then
	echo
	if [ `grep user=root $CONFIGDIR/config-root` ]; then
		echo "Note: CDWserver currently runs with root privileges."
	fi
	if [ -z "$NOINFO" ]; then
		echo "To configure the user and group of CDWserver run"
		echo
		echo "        $SBINDIR/CDWconfig.sh --help"
		echo
	fi
	exit 0
fi

# set the owner of the config and log files
/bin/chown $USER $CONFIGDIR/accounts 2> /dev/null || :
/bin/chown $USER $CONFIGDIR/config 2> /dev/null || :
/bin/chown $USER $CONFIGDIR/key.txt 2> /dev/null || :
/bin/chown $USER $CONFIGDIR/password 2> /dev/null || :
/bin/chmod 600 $CONFIGDIR/password 2> /dev/null || :
/bin/chown $USER $LOGDIR/CDinfos 2> /dev/null || :
/bin/chown $USER $LOGDIR/connects 2> /dev/null || :
/bin/chown $USER $LOGDIR/log 2> /dev/null || :
/bin/chown $USER $LOGDIR/sessions 2> /dev/null || :
/bin/chown $USER $GROUP $PROJECTSDIR $LOGDIR $SPOOLDIR 2> /dev/null || :

# make "setuid root copies" of cdrdao, cdrecord, mkisofs and readcd
for tool in cdrdao cdrecord genisoimage mkisofs readcd readom wodim
do
	if [ ! -e $TOOLSDIR/$tool ]; then
		if [ -e /usr/bin/$tool ]; then
			cp -af /usr/bin/$tool $TOOLSDIR/ || :
		else
			cp -af /usr/local/bin/$tool $TOOLSDIR/ 2> /dev/null || :
		fi
	fi
	if [ -e $TOOLSDIR/$tool ]; then
		chown root.$GROUP $TOOLSDIR/$tool || :
		if [ "$SETUID" = on ]; then
			chmod 4750 $TOOLSDIR/$tool || :
		else
			chmod 755 $TOOLSDIR/$tool || :
		fi
	fi
done

# set some tools to "setuid root"
TOOLSDIR=/usr/bin
for tool in CDWrootGate CDWverify
do
	if [ -e $TOOLSDIR/$tool ]; then
		chown root.$GROUP $TOOLSDIR/$tool || :
		chmod 4710 $TOOLSDIR/$tool || :
	fi
done

cat > $CONFIGDIR/config-root << EOF
#
# This file was generated by $SBINDIR/CDWconfig.sh
#
# To configure the user and group of CDWserver see
#
#    $SBINDIR/CDWconfig.sh --help
#

user=$USER
group=$GROUP
setuid=$SETUID

EOF

if [ -z "$NORESTART" ]; then
	$INITDIR/CDWserver restart
fi
